/*
 * Copyright (C) 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.car.settings.network;

import static org.mockito.Mockito.verify;

import android.app.AlertDialog;
import android.content.DialogInterface;

import com.android.car.settings.CarSettingsRobolectricTestRunner;
import com.android.car.settings.testutils.BaseTestActivity;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.robolectric.Robolectric;
import org.robolectric.shadows.ShadowDialog;

@RunWith(CarSettingsRobolectricTestRunner.class)
public class ConfirmMobileDataDisableDialogTest {

    private ConfirmMobileDataDisableDialog mDialog;
    @Mock
    private ConfirmMobileDataDisableDialog.ConfirmMobileDataDisableListener mListener;

    @Before
    public void setUp() {
        MockitoAnnotations.initMocks(this);
        mDialog = new ConfirmMobileDataDisableDialog();
        mDialog.setListener(mListener);
    }

    @Test
    public void confirmDisable_disableCallbackCalled() {
        AlertDialog dialog = showDialog(mDialog);
        dialog.getButton(DialogInterface.BUTTON_POSITIVE).performClick();

        verify(mListener).onMobileDataDisableConfirmed();
    }

    @Test
    public void rejectDisable_rejectCallbackCalled() {
        AlertDialog dialog = showDialog(mDialog);
        dialog.getButton(DialogInterface.BUTTON_NEGATIVE).performClick();

        verify(mListener).onMobileDataDisableRejected();
    }

    private AlertDialog showDialog(ConfirmMobileDataDisableDialog fragment) {
        BaseTestActivity activity = Robolectric.setupActivity(BaseTestActivity.class);
        activity.showDialog(fragment, /* tag= */ null);
        return (AlertDialog) ShadowDialog.getLatestDialog();
    }
}
